@@ -46,12 +46,11 @@ class Graph():
         for v in self._vertices:
             if v in visited:
                 continue
-            component = []
+            component = [v]
             q = [v]
             visited.append(v)
             while q:
                 v = q.pop()
-                component.append(v)
                 for adj_v in self.data[v].keys():
                     if not adj_v in visited:
                         visited.append(adj_v)
@@ -105,3 +104,5 @@ class Graph():
     @property
     def vertices(self):
         return self._vertices
+
+
